@@ -454,11 +454,40 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
     if custom_sections:
         main_section_parts.extend(custom_sections)
 
+    # Handle Methods section based on methods_placement configuration
+    methods_placement = yaml_metadata.get("methods_placement", "inline")
+    methods_content = content_sections.get("methods", "").strip()
+
+    # Map numeric values to string options for backward compatibility
+    numeric_mapping = {
+        1: "inline",
+        2: "after_results",
+        3: "after_bibliography",
+    }
+
+    if isinstance(methods_placement, int) and methods_placement in numeric_mapping:
+        methods_placement = numeric_mapping[methods_placement]
+
+    # Validate methods_placement value and fallback to "inline" if invalid
+    valid_placements = ["inline", "after_results", "after_bibliography"]
+    if methods_placement not in valid_placements:
+        import sys
+
+        print(
+            f'⚠️  Warning: Invalid methods_placement value "{methods_placement}". '
+            f'Using "inline" as fallback. Valid options: {", ".join(valid_placements)} or numeric values 1-3',
+            file=sys.stderr,
+        )
+        methods_placement = "inline"
+
+    if methods_placement == "inline" and methods_content:
+        # Methods should appear inline in content - add it to main section with header
+        main_section_parts.append(f"\\section*{{Methods}}\n{methods_content}")
+
     # Combine all parts into the final main section
     main_section = "\n\n".join(main_section_parts) if main_section_parts else ""
 
     template_content = template_content.replace("<PY-RPL:MAIN-SECTION>", main_section)
-    template_content = template_content.replace("<PY-RPL:METHODS>", content_sections.get("methods", ""))
 
     # Handle main content sections conditionally
     # Results section
@@ -485,6 +514,19 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
         conclusions_section = ""
     template_content = template_content.replace("<PY-RPL:CONCLUSIONS-SECTION>", conclusions_section)
 
+    # Handle Methods section placement based on configuration
+    if methods_placement == "after_results" and methods_content:
+        methods_section = f"\\section*{{Methods}}\n{methods_content}"
+        template_content = template_content.replace("<PY-RPL:METHODS-AFTER-RESULTS>", methods_section)
+    else:
+        template_content = template_content.replace("<PY-RPL:METHODS-AFTER-RESULTS>", "")
+
+    if methods_placement == "after_bibliography" and methods_content:
+        methods_section = f"\\section*{{Methods}}\n{methods_content}"
+        template_content = template_content.replace("<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>", methods_section)
+    else:
+        template_content = template_content.replace("<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>", "")
+
     # Handle optional sections conditionally
     # Data availability
     data_availability = content_sections.get("data_availability", "").strip()
