@@ -1,87 +1,62 @@
 """Pytest configuration and fixtures for Rxiv-Maker tests."""
 
+import gc
+import os
 import shutil
 import subprocess
 import tempfile
 from pathlib import Path
-from typing import Any
 
 import pytest
 
-# --- Helper Class for Engine Abstraction ---
+# Import cleanup utilities if available
+try:
+    import sys
+
+    sys.path.insert(0, str(Path(__file__).parent.parent / "nox_utils"))
+    # from nox_utils import DiskSpaceMonitor, cleanup_manager
+
+    CLEANUP_AVAILABLE = True
+except ImportError:
+    CLEANUP_AVAILABLE = False
+
+
+# --- Helper Class for Local Engine Execution ---
 
 
 class ExecutionEngine:
-    """A helper class to abstract command execution."""
+    """A helper class for local command execution."""
 
-    def __init__(self, engine_type: str, container_id: str | None = None):
+    def __init__(self, engine_type: str = "local"):
+        if engine_type != "local":
+            raise ValueError(f"Only local engine is supported, got: {engine_type}")
         self.engine_type = engine_type
-        self.container_id = container_id
-        print(f"\n✅ Engine initialized: type={self.engine_type}, container_id={self.container_id}")
+        print(f"\n✅ Engine initialized: type={self.engine_type}")
 
-    def run(self, command: list[str], **kwargs: Any) -> subprocess.CompletedProcess:
-        """Runs a command in the selected engine."""
+    def run(self, command: list[str], **kwargs) -> subprocess.CompletedProcess:
+        """Runs a command using local execution."""
         # Extract check parameter, default to True
         check = kwargs.pop("check", True)
 
         # Extract timeout parameter, default to 600 seconds (10 minutes) for long operations
         timeout = kwargs.pop("timeout", 600)
 
-        # Common kwargs for all engines
+        # Common kwargs for local execution
         run_kwargs = {"text": True, "capture_output": True, "check": check, "timeout": timeout, **kwargs}
 
-        if self.engine_type == "local":
-            return subprocess.run(command, **run_kwargs)
-
-        # Assumes podman commands are compatible with docker for exec
-        if self.engine_type in ["docker", "podman"]:
-            if self.container_id is None:
-                raise ValueError(f"Container ID required for {self.engine_type} engine")
-
-            # For containerized engines, handle cwd by using sh -c with cd
-            if "cwd" in kwargs:
-                cwd = kwargs.pop("cwd")
-                # Remove cwd from run_kwargs since it doesn't apply to host execution of docker
-                if "cwd" in run_kwargs:
-                    del run_kwargs["cwd"]
-                # Properly quote command arguments for shell
-                import shlex
-
-                quoted_command = " ".join(shlex.quote(arg) for arg in command)
-                # Use sh -c to change directory before executing command
-                shell_command = f"cd {shlex.quote(cwd)} && {quoted_command}"
-                base_command = [
-                    self.engine_type,
-                    "exec",
-                    self.container_id,
-                    "sh",
-                    "-c",
-                    shell_command,
-                ]
-                return subprocess.run(base_command, **run_kwargs)
-            else:
-                base_command = [self.engine_type, "exec", self.container_id]
-                full_command = base_command + command
-                return subprocess.run(full_command, **run_kwargs)
-
-        raise ValueError(f"Unsupported engine type: {self.engine_type}")
+        return subprocess.run(command, **run_kwargs)
 
     def rxiv_command(self, *args, **kwargs) -> subprocess.CompletedProcess:
-        """Standardized rxiv command execution across engines."""
+        """Standardized rxiv command execution for local engine."""
         import sys
 
-        if self.engine_type == "local":
-            try:
-                # Try uv run first (modern approach)
-                cmd = ["uv", "run", "rxiv"] + list(args)
-                return self.run(cmd, **kwargs)
-            except (FileNotFoundError, subprocess.CalledProcessError):
-                # Fallback to python module
-                cmd = [sys.executable, "-m", "rxiv_maker.cli"] + list(args)
-                return self.run(cmd, **kwargs)
-        else:
-            # In containers, rxiv should be installed
-            cmd = ["rxiv"] + list(args)
+        try:
+            # Try uv run first (modern approach)
+            cmd = ["uv", "run", "rxiv"] + list(args)
+            return self.run(cmd, **kwargs)
+        except (FileNotFoundError, subprocess.CalledProcessError):
+            # Fallback to python module
+            cmd = [sys.executable, "-m", "rxiv_maker.cli"] + list(args)
             return self.run(cmd, **kwargs)
 
 
@@ -89,82 +64,26 @@ class ExecutionEngine:
 
 
 def pytest_addoption(parser):
-    """Adds the --engine command-line option to pytest."""
+    """Adds the --engine command-line option to pytest (local only)."""
     parser.addoption(
         "--engine",
         action="store",
         default="local",
-        help="Specify the execution engine: local, docker, podman",
+        help="Specify the execution engine: local (only supported option)",
     )
 
 
 @pytest.fixture(scope="session")
 def execution_engine(request):
     """
-    A session-scoped fixture that sets up and tears down the
-    specified execution engine (e.g., a Docker container).
+    Session-scoped fixture for local execution engine.
     """
     engine_name = request.config.getoption("--engine")
 
-    if engine_name == "local":
-        yield ExecutionEngine("local")
-        return
+    if engine_name != "local":
+        pytest.fail(f"Only local engine is supported. Docker/Podman engines are deprecated. Got: {engine_name}")
 
-    # --- Containerized Engines (Docker, Podman, etc.) ---
-    container_id = None
-    try:
-        if engine_name in ["docker", "podman"]:
-            # Use the existing rxiv-maker base image from Docker Hub
-            docker_image = "henriqueslab/rxiv-maker-base:latest"
-
-            print(f"\n🐳 Pulling {engine_name} image: {docker_image}")
-            subprocess.run([engine_name, "pull", docker_image], check=True)
-
-            # Run the container in detached mode with workspace mounted
-            result = subprocess.run(
-                [
-                    engine_name,
-                    "run",
-                    "-d",
-                    "--rm",
-                    "-v",
-                    f"{Path.cwd()}:/workspace",
-                    "-w",
-                    "/workspace",
-                    docker_image,
-                    "sleep",
-                    "infinity",
-                ],
-                check=True,
-                text=True,
-                capture_output=True,
-            )
-            container_id = result.stdout.strip()
-            print(f"\n🚀 Started {engine_name} container: {container_id[:12]}")
-
-            # Install rxiv-maker in the container
-            print("\n📦 Installing rxiv-maker in container...")
-            subprocess.run(
-                [
-                    engine_name,
-                    "exec",
-                    container_id,
-                    "pip",
-                    "install",
-                    "-e",
-                    "/workspace",
-                ],
-                check=True,
-            )
-
-            yield ExecutionEngine(engine_name, container_id)
-        else:
-            pytest.fail(f"Unsupported engine: {engine_name}")
-
-    finally:
-        if container_id:
-            print(f"\n🛑 Stopping {engine_name} container: {container_id[:12]}")
-            subprocess.run([engine_name, "stop", container_id], check=False, capture_output=True)
+    yield ExecutionEngine("local")
 
 
 # --- Optimized Temporary Directory Fixtures ---
@@ -322,13 +241,13 @@ def pytest_collection_modifyitems(config: pytest.Config, items: list[pytest.Item
         ):
             item.add_marker(requires_latex)
 
-        # Docker dependency detection
+        # Docker dependency detection (deprecated - for cleanup identification)
         if "docker" in test_name_lower or "container" in test_name_lower or "docker_engine" in test_file:
-            item.add_marker(requires_docker)
+            item.add_marker(pytest.mark.skip(reason="Docker engine deprecated - use local execution only"))
 
-        # Podman dependency detection
+        # Podman dependency detection (deprecated - for cleanup identification)
         if "podman" in test_name_lower or "podman_engine" in test_file:
-            item.add_marker(requires_podman)
+            item.add_marker(pytest.mark.skip(reason="Podman engine deprecated - use local execution only"))
 
         # R dependency detection
         if "r_" in test_name_lower or "_r_" in test_name_lower or "test_r" in test_name_lower:
@@ -336,7 +255,6 @@ def pytest_collection_modifyitems(config: pytest.Config, items: list[pytest.Item
 
         # Heavier or brittle unit tests to exclude by default in CI
         heavy_unit_files = {
-            "tests/unit/test_docker_engine_mode.py",
             "tests/unit/test_platform_detector.py",
             "tests/unit/test_figure_generator.py",
             "tests/unit/test_github_actions_integration.py",
@@ -353,7 +271,6 @@ def pytest_collection_modifyitems(config: pytest.Config, items: list[pytest.Item
 
 def copy_tree_optimized(src: Path, dst: Path, use_hardlinks: bool = True):
     """Enhanced optimized tree copying with better hardlink strategy."""
-    import os
 
     dst.mkdir(parents=True, exist_ok=True)
 
@@ -471,9 +388,36 @@ def minimal_manuscript(minimal_manuscript_template, temp_dir):
 def check_latex_available():
     """Check if LaTeX is available in the system."""
     try:
-        result = subprocess.run(["pdflatex", "--version"], capture_output=True, text=True)
-        return result.returncode == 0
-    except (FileNotFoundError, OSError):
+        # First check if pdflatex exists and runs
+        result = subprocess.run(["pdflatex", "--version"], capture_output=True, text=True, timeout=10)
+        if result.returncode != 0:
+            return False
+
+        # Additional check: try to compile a minimal LaTeX document
+        import tempfile
+
+        test_content = r"""
+\documentclass{article}
+\begin{document}
+Test
+\end{document}
+"""
+        with tempfile.TemporaryDirectory() as tmpdir:
+            test_file = Path(tmpdir) / "test.tex"
+            test_file.write_text(test_content)
+
+            compile_result = subprocess.run(
+                ["pdflatex", "-interaction=nonstopmode", "-output-directory", tmpdir, str(test_file)],
+                capture_output=True,
+                text=True,
+                timeout=30,
+            )
+
+            # Check if PDF was created successfully
+            pdf_file = Path(tmpdir) / "test.pdf"
+            return compile_result.returncode == 0 and pdf_file.exists() and pdf_file.stat().st_size > 0
+
+    except (FileNotFoundError, OSError, subprocess.TimeoutExpired):
         return False
 
 
@@ -486,29 +430,23 @@ def check_r_available():
         return False
 
 
+# Docker and Podman availability checks removed - engines deprecated
+# These functions kept as no-op for backward compatibility
 def check_docker_available():
-    """Check if Docker is available in the system."""
-    try:
-        result = subprocess.run(["docker", "--version"], capture_output=True, text=True)
-        return result.returncode == 0
-    except (FileNotFoundError, OSError):
-        return False
+    """Docker availability check (deprecated - always returns False)."""
+    return False
 
 
 def check_podman_available():
-    """Check if Podman is available in the system."""
-    try:
-        result = subprocess.run(["podman", "--version"], capture_output=True, text=True)
-        return result.returncode == 0
-    except (FileNotFoundError, OSError):
-        return False
+    """Podman availability check (deprecated - always returns False)."""
+    return False
 
 
 # Markers for conditional test execution
 requires_latex = pytest.mark.skipif(not check_latex_available(), reason="LaTeX not available")
 requires_r = pytest.mark.skipif(not check_r_available(), reason="R not available")
-requires_docker = pytest.mark.skipif(not check_docker_available(), reason="Docker not available")
-requires_podman = pytest.mark.skipif(not check_podman_available(), reason="Podman not available")
+requires_docker = pytest.mark.skip(reason="Docker engine deprecated - use local execution")
+requires_podman = pytest.mark.skip(reason="Podman engine deprecated - use local execution")
 
 # Test category markers (don't skip, just mark for selection)
 pytest.mark.unit = pytest.mark.unit
@@ -622,81 +560,21 @@ Missing proper structure.
 
 @pytest.fixture(scope="class")
 def class_execution_engine(request):
-    """Class-scoped execution engine for tests that can share container setup."""
+    """Class-scoped fixture for local execution engine."""
     engine_name = request.config.getoption("--engine")
 
-    if engine_name == "local":
-        yield ExecutionEngine("local")
-        return
+    if engine_name != "local":
+        pytest.fail(f"Only local engine is supported. Docker/Podman engines are deprecated. Got: {engine_name}")
 
-    # --- Containerized Engines (Docker, Podman, etc.) ---
-    container_id = None
-    try:
-        if engine_name in ["docker", "podman"]:
-            # Use the existing rxiv-maker base image from Docker Hub
-            docker_image = "henriqueslab/rxiv-maker-base:latest"
-
-            print(f"\n🐳 Pulling {engine_name} image: {docker_image}")
-            subprocess.run([engine_name, "pull", docker_image], check=True)
-
-            # Run the container in detached mode with workspace mounted
-            result = subprocess.run(
-                [
-                    engine_name,
-                    "run",
-                    "-d",
-                    "-v",
-                    f"{Path.cwd()}:/workspace",
-                    "--workdir",
-                    "/workspace",
-                    docker_image,
-                    "sleep",
-                    "3600",  # Keep container alive for 1 hour
-                ],
-                capture_output=True,
-                text=True,
-                check=True,
-            )
-            container_id = result.stdout.strip()
-            print(f"✅ Container started: {container_id[:12]}")
-
-            # Install rxiv-maker in the container
-            print("📦 Installing rxiv-maker in container...")
-            subprocess.run(
-                [
-                    engine_name,
-                    "exec",
-                    container_id,
-                    "pip",
-                    "install",
-                    "-e",
-                    "/workspace",
-                ],
-                check=True,
-            )
-            print("✅ rxiv-maker installed successfully")
-
-            yield ExecutionEngine(engine_name, container_id)
-
-        else:
-            raise ValueError(f"Unsupported engine: {engine_name}")
-
-    finally:
-        # Clean up container
-        if container_id:
-            print(f"\n🧹 Cleaning up container: {container_id[:12]}")
-            subprocess.run([engine_name, "rm", "-f", container_id], check=False)
+    yield ExecutionEngine("local")
 
 
 @pytest.fixture(autouse=True)
 def test_isolation():
-    """Ensure test isolation by cleaning up state."""
-    # Pre-test setup
+    """Basic test isolation - optimized for performance."""
     yield
-    # Post-test cleanup
-    import gc
-    import os
 
+    # Lightweight post-test cleanup
     # Clear any lingering environment variables
     test_env_vars = [var for var in os.environ if var.startswith("RXIV_TEST_")]
     for var in test_env_vars:
