@@ -25,20 +25,20 @@ class TestBuildCommand:
         # Click should show its own error message for invalid path
         assert "does not exist" in result.output.lower() or "invalid" in result.output.lower()
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
-    def test_successful_pdf_generation(self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory):
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.core.progress_framework.progress_operation")
+    def test_successful_pdf_generation(self, mock_progress_operation, mock_build_manager):
         """Test successful PDF generation."""
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
-        # Mock Progress
-        mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        # Mock progress_operation context manager
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=MagicMock())
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress_operation.return_value = mock_progress_context
 
         # Use a real temporary directory that exists to pass Click validation
         with self.runner.isolated_filesystem():
@@ -48,23 +48,23 @@ class TestBuildCommand:
 
         assert result.exit_code == 0
         mock_build_manager.assert_called_once()
-        mock_manager.run_full_build.assert_called_once()
-        mock_cleanup.assert_called_once()
+        mock_manager.build.assert_called_once()
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
-    def test_build_failure(self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory):
+    @patch("rxiv_maker.core.logging_config.set_log_directory")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.core.progress_framework.progress_operation")
+    def test_build_failure(self, mock_progress_operation, mock_build_manager, mock_set_log_directory):
         """Test PDF generation failure."""
         # Mock BuildManager with failure
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = False
+        mock_manager.build.return_value = False
         mock_build_manager.return_value = mock_manager
 
-        # Mock Progress
-        mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        # Mock progress_operation context manager
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=MagicMock())
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress_operation.return_value = mock_progress_context
 
         # Use a real temporary directory that exists to pass Click validation
         with self.runner.isolated_filesystem():
@@ -73,24 +73,23 @@ class TestBuildCommand:
             result = self.runner.invoke(build, ["test_manuscript"], obj={"verbose": False, "engine": "local"})
 
         assert result.exit_code == 1
-        mock_manager.run_full_build.assert_called_once()
-        # cleanup gets called multiple times (finally block + error handling)
-        assert mock_cleanup.call_count >= 1
+        mock_manager.build.assert_called_once()
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
-    def test_keyboard_interrupt_handling(self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory):
+    @patch("rxiv_maker.core.logging_config.set_log_directory")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.core.progress_framework.progress_operation")
+    def test_keyboard_interrupt_handling(self, mock_progress_operation, mock_build_manager, mock_set_log_directory):
         """Test keyboard interrupt handling."""
         # Mock BuildManager to raise KeyboardInterrupt
         mock_manager = MagicMock()
-        mock_manager.run_full_build.side_effect = KeyboardInterrupt()
+        mock_manager.build.side_effect = KeyboardInterrupt()
         mock_build_manager.return_value = mock_manager
 
-        # Mock Progress
-        mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        # Mock progress_operation context manager
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=MagicMock())
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress_operation.return_value = mock_progress_context
 
         # Use a real temporary directory that exists to pass Click validation
         with self.runner.isolated_filesystem():
@@ -99,24 +98,23 @@ class TestBuildCommand:
             result = self.runner.invoke(build, ["test_manuscript"], obj={"verbose": False, "engine": "local"})
 
         assert result.exit_code == 1
-        assert "PDF generation interrupted by user" in result.output
-        # cleanup gets called multiple times (finally block + error handling)
-        assert mock_cleanup.call_count >= 1
+        assert "build interrupted by user" in result.output
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
-    def test_unexpected_error_handling(self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory):
+    @patch("rxiv_maker.core.logging_config.set_log_directory")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.core.progress_framework.progress_operation")
+    def test_unexpected_error_handling(self, mock_progress_operation, mock_build_manager, mock_set_log_directory):
         """Test unexpected error handling."""
         # Mock BuildManager to raise unexpected error
         mock_manager = MagicMock()
-        mock_manager.run_full_build.side_effect = RuntimeError("Unexpected error")
+        mock_manager.build.side_effect = RuntimeError("Unexpected error")
         mock_build_manager.return_value = mock_manager
 
-        # Mock Progress
-        mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        # Mock progress_operation context manager
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=MagicMock())
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress_operation.return_value = mock_progress_context
 
         # Use a real temporary directory that exists to pass Click validation
         with self.runner.isolated_filesystem():
@@ -125,26 +123,26 @@ class TestBuildCommand:
             result = self.runner.invoke(build, ["test_manuscript"], obj={"verbose": False, "engine": "local"})
 
         assert result.exit_code == 1
-        assert "Unexpected error: Unexpected error" in result.output
-        # cleanup gets called multiple times (finally block + error handling)
-        assert mock_cleanup.call_count >= 1
+        # Error message should contain the actual error
+        assert "Unexpected error" in result.output
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
+    @patch("rxiv_maker.core.logging_config.set_log_directory")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.core.progress_framework.progress_operation")
     def test_default_manuscript_path_from_env(
-        self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory
+        self, mock_progress_operation, mock_build_manager, mock_set_log_directory
     ):
         """Test using MANUSCRIPT_PATH environment variable."""
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
-        # Mock Progress
-        mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        # Mock progress_operation context manager
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=MagicMock())
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress_operation.return_value = mock_progress_context
 
         # Test with environment variable
         with self.runner.isolated_filesystem():
@@ -155,22 +153,23 @@ class TestBuildCommand:
         assert result.exit_code == 0
         # Verify BuildManager was called with the environment variable value
         args, kwargs = mock_build_manager.call_args
-        assert kwargs["manuscript_path"] == "custom_manuscript"
+        assert kwargs["manuscript_path"].endswith("custom_manuscript")
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
-    def test_build_options(self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory):
+    @patch("rxiv_maker.core.logging_config.set_log_directory")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.core.progress_framework.progress_operation")
+    def test_build_options(self, mock_progress_operation, mock_build_manager, mock_set_log_directory):
         """Test various build options."""
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
-        # Mock Progress
-        mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        # Mock progress_operation context manager
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=MagicMock())
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress_operation.return_value = mock_progress_context
 
         # Use a real temporary directory
         with self.runner.isolated_filesystem():
@@ -194,69 +193,34 @@ class TestBuildCommand:
 
         # Verify BuildManager was called with correct options
         args, kwargs = mock_build_manager.call_args
-        assert kwargs["manuscript_path"] == "test_manuscript"
+        assert kwargs["manuscript_path"].endswith("test_manuscript")
         assert kwargs["output_dir"] == "custom_output"
         assert kwargs["force_figures"] is True
         assert kwargs["skip_validation"] is True
         assert kwargs["track_changes_tag"] == "v1.0.0"
         assert kwargs["verbose"] is True
 
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.docker.manager.get_docker_manager")
-    def test_docker_engine_availability_check(self, mock_get_docker_manager, mock_set_log_directory):
-        """Test Docker engine availability check."""
-        # Mock Docker manager unavailable
-        mock_docker_manager = MagicMock()
-        mock_docker_manager.check_docker_available.return_value = False
-        mock_get_docker_manager.return_value = mock_docker_manager
-
-        # Create context with docker engine and use real directory
-        with self.runner.isolated_filesystem():
-            os.makedirs("test_manuscript")
-            result = self.runner.invoke(build, ["test_manuscript"], obj={"engine": "docker"})
-
-        assert result.exit_code == 1
-        assert "Docker is not available for build pipeline" in result.output
-        assert "Use --engine local to build without Docker" in result.output
-
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.docker.manager.get_docker_manager")
-    @patch("rxiv_maker.cli.commands.build.logger")
-    def test_docker_engine_setup_error(self, mock_logger, mock_get_docker_manager, mock_set_log_directory):
-        """Test Docker engine setup error."""
-        # Mock Docker manager setup error
-        mock_get_docker_manager.side_effect = Exception("Docker setup failed")
-
-        # Create context with docker engine and use real directory
-        with self.runner.isolated_filesystem():
-            os.makedirs("test_manuscript")
-            result = self.runner.invoke(build, ["test_manuscript"], obj={"engine": "docker"})
-
-        assert result.exit_code == 1
-        # Verify the error was logged correctly
-        mock_logger.error.assert_called_with("Docker setup error: Docker setup failed")
-
-    @patch("rxiv_maker.cli.commands.build.set_debug")
-    @patch("rxiv_maker.cli.commands.build.set_quiet")
-    @patch("rxiv_maker.cli.commands.build.Path")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
+    @patch("rxiv_maker.core.logging_config.set_debug")
+    @patch("rxiv_maker.core.logging_config.set_quiet")
+    @patch("rxiv_maker.cli.framework.Path")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.cli.framework.Progress")
     @pytest.mark.skip(reason="Complex mocking test - needs refactoring")
-    def test_logging_configuration(
-        self, mock_cleanup, mock_progress, mock_build_manager, mock_path, mock_set_quiet, mock_set_debug
-    ):
+    def test_logging_configuration(self, mock_progress, mock_build_manager, mock_path, mock_set_quiet, mock_set_debug):
         """Test logging configuration based on flags."""
         mock_path.return_value.exists.return_value = True
 
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
         # Mock Progress
         mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=mock_progress_instance)
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress.return_value = mock_progress_context
 
         # Test debug flag with real directory
         with self.runner.isolated_filesystem():
@@ -278,15 +242,12 @@ class TestBuildCommand:
             assert result.exit_code == 0
             mock_set_quiet.assert_called_with(True)
 
-    @patch("rxiv_maker.cli.commands.build.Path")
-    @patch("rxiv_maker.cli.commands.build.set_log_directory")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
+    @patch("rxiv_maker.cli.framework.Path")
+    @patch("rxiv_maker.core.logging_config.set_log_directory")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.cli.framework.Progress")
     @pytest.mark.skip(reason="Complex mocking test - needs refactoring")
-    def test_output_directory_handling(
-        self, mock_cleanup, mock_progress, mock_build_manager, mock_set_log_directory, mock_path
-    ):
+    def test_output_directory_handling(self, mock_progress, mock_build_manager, mock_set_log_directory, mock_path):
         """Test output directory handling."""
         mock_path_instance = MagicMock()
         mock_path.return_value = mock_path_instance
@@ -295,12 +256,15 @@ class TestBuildCommand:
 
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
         # Mock Progress
         mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=mock_progress_instance)
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress.return_value = mock_progress_context
 
         result = self.runner.invoke(build, ["test_manuscript", "--output-dir", "custom_output"])
 
@@ -308,32 +272,34 @@ class TestBuildCommand:
         # Verify log directory was set
         mock_set_log_directory.assert_called_once()
 
-    @patch("rxiv_maker.cli.commands.build.Path")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
+    @patch("rxiv_maker.cli.framework.Path")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.cli.framework.Progress")
     @pytest.mark.skip(reason="Complex mocking test - needs refactoring")
-    def test_progress_callback_handling(self, mock_cleanup, mock_progress, mock_build_manager, mock_path):
+    def test_progress_callback_handling(self, mock_progress, mock_build_manager, mock_path):
         """Test progress callback functionality."""
         mock_path.return_value.exists.return_value = True
 
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
         # Mock Progress
         mock_progress_instance = MagicMock()
         mock_task = MagicMock()
         mock_progress_instance.add_task.return_value = mock_task
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=mock_progress_instance)
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress.return_value = mock_progress_context
 
         result = self.runner.invoke(build, ["test_manuscript"])
 
         assert result.exit_code == 0
 
-        # Verify progress callback was passed to run_full_build
-        args, kwargs = mock_manager.run_full_build.call_args
+        # Verify progress callback was passed to build
+        args, kwargs = mock_manager.build.call_args
         assert "progress_callback" in kwargs
         assert callable(kwargs["progress_callback"])
 
@@ -350,23 +316,25 @@ class TestBuildCommandEdgeCases:
         """Set up test fixtures."""
         self.runner = CliRunner()
 
-    @patch("rxiv_maker.cli.commands.build.Path")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
+    @patch("rxiv_maker.cli.framework.Path")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.cli.framework.Progress")
     @pytest.mark.skip(reason="Complex mocking test - needs refactoring")
-    def test_skip_validation_removes_step(self, mock_cleanup, mock_progress, mock_build_manager, mock_path):
+    def test_skip_validation_removes_step(self, mock_progress, mock_build_manager, mock_path):
         """Test that skip-validation removes validation step from progress."""
         mock_path.return_value.exists.return_value = True
 
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
         # Mock Progress
         mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=mock_progress_instance)
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress.return_value = mock_progress_context
 
         result = self.runner.invoke(build, ["test_manuscript", "--skip-validation"])
 
@@ -381,24 +349,26 @@ class TestBuildCommandEdgeCases:
         # Normal build has 10 steps, skip-validation should have 9
         assert total_steps == 9
 
-    @patch("rxiv_maker.cli.commands.build.Path")
-    @patch("rxiv_maker.cli.commands.build.BuildManager")
-    @patch("rxiv_maker.cli.commands.build.Progress")
-    @patch("rxiv_maker.core.logging_config.cleanup")
+    @patch("rxiv_maker.cli.framework.Path")
+    @patch("rxiv_maker.engines.operations.build_manager.BuildManager")
+    @patch("rxiv_maker.cli.framework.Progress")
     @pytest.mark.skip(reason="Complex mocking test - needs refactoring")
-    def test_build_success_output_messages(self, mock_cleanup, mock_progress, mock_build_manager, mock_path):
+    def test_build_success_output_messages(self, mock_progress, mock_build_manager, mock_path):
         """Test success output messages."""
         mock_path.return_value.exists.return_value = True
         mock_path.return_value.name = "test_manuscript"
 
         # Mock BuildManager
         mock_manager = MagicMock()
-        mock_manager.run_full_build.return_value = True
+        mock_manager.build.return_value = True
         mock_build_manager.return_value = mock_manager
 
         # Mock Progress
         mock_progress_instance = MagicMock()
-        mock_progress.return_value.__enter__.return_value = mock_progress_instance
+        mock_progress_context = MagicMock()
+        mock_progress_context.__enter__ = MagicMock(return_value=mock_progress_instance)
+        mock_progress_context.__exit__ = MagicMock(return_value=None)
+        mock_progress.return_value = mock_progress_context
 
         result = self.runner.invoke(build, ["test_manuscript", "--track-changes", "v1.0.0", "--force-figures"])
 
@@ -406,28 +376,28 @@ class TestBuildCommandEdgeCases:
         # These messages should appear in the logs, not necessarily in CLI output
         # The test verifies the command completes successfully with these options
 
-    @patch("rxiv_maker.cli.commands.build.Path")
-    def test_absolute_output_path_handling(self, mock_path):
-        """Test handling of absolute output paths."""
-        # Mock manuscript path exists
-        mock_manuscript_path = MagicMock()
-        mock_manuscript_path.exists.return_value = True
+    @patch("rxiv_maker.cli.framework.base.PathManager")
+    def test_absolute_output_path_handling(self, mock_path_manager):
+        """Test handling of absolute output paths through PathManager."""
+        # Mock PathManager instance
+        mock_path_manager_instance = MagicMock()
+        mock_path_manager_instance.manuscript_path = "/absolute/path/to/manuscript"
+        mock_path_manager_instance.output_dir = "/absolute/path/to/output"
+        mock_path_manager.return_value = mock_path_manager_instance
 
-        # Mock output path as absolute
-        mock_output_path = MagicMock()
-        mock_output_path.is_absolute.return_value = True
+        # Use a real temporary directory that exists to pass Click validation
+        with self.runner.isolated_filesystem():
+            # Create a test manuscript directory
+            os.makedirs("test_manuscript")
 
-        def path_side_effect(path_str):
-            if "output" in str(path_str):
-                return mock_output_path
-            else:
-                return mock_manuscript_path
+            # Test with absolute output path - this should work through PathManager
+            self.runner.invoke(
+                build,
+                ["test_manuscript", "--output-dir", "/absolute/output/path"],
+                obj={"verbose": False, "engine": "local"},
+            )
 
-        mock_path.side_effect = path_side_effect
-
-        # This test mainly verifies the path handling logic doesn't crash
-        # The actual BuildManager and Progress mocking would make this test too complex
-        # So we just test that the path logic works correctly
-
-        # Test that absolute path handling logic works
-        assert mock_output_path.is_absolute() is True
+        # The command should handle absolute paths through PathManager
+        # Even if it fails later (due to missing BuildManager setup),
+        # the PathManager should be created successfully
+        mock_path_manager.assert_called_once()
