@@ -137,3 +137,91 @@ Custom manuscript preparation content here.
         # Should contain the custom content, not the default acknowledgment
         assert "Custom manuscript preparation content here" in result
         assert "This manuscript was prepared using" not in result
+
+    def test_methods_placement_inline(self):
+        """Test that Methods appears inline when methods_placement is inline."""
+        template_content = """<PY-RPL:MAIN-SECTION>
+<PY-RPL:METHODS-AFTER-RESULTS>
+<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>"""
+        yaml_metadata = {"methods_placement": "inline"}
+        article_md = """## Introduction
+
+This is the introduction.
+
+## Methods
+
+This is the methods section.
+"""
+
+        result = process_template_replacements(template_content, yaml_metadata, article_md)
+
+        # Methods should appear in MAIN-SECTION with header
+        assert "\\section*{Methods}" in result
+        assert "This is the methods section" in result
+        # Other placeholders should be empty
+        # The result should not have Methods appearing twice
+
+    def test_methods_placement_after_results(self):
+        """Test that Methods appears after Results when methods_placement is after_results."""
+        template_content = """<PY-RPL:MAIN-SECTION>
+<PY-RPL:RESULTS-SECTION>
+<PY-RPL:METHODS-AFTER-RESULTS>
+<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>"""
+        yaml_metadata = {"methods_placement": "after_results"}
+        article_md = """## Introduction
+
+This is the introduction.
+
+## Methods
+
+This is the methods section.
+"""
+
+        result = process_template_replacements(template_content, yaml_metadata, article_md)
+
+        # Methods should appear in the METHODS-AFTER-RESULTS placeholder
+        assert "\\section*{Methods}" in result
+        assert "This is the methods section" in result
+        # Verify Methods is not in MAIN-SECTION (Introduction should be there, but not Methods)
+
+    def test_methods_placement_after_bibliography(self):
+        """Test that Methods appears after Bibliography when methods_placement is after_bibliography."""
+        template_content = """<PY-RPL:MAIN-SECTION>
+<PY-RPL:METHODS-AFTER-RESULTS>
+<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>"""
+        yaml_metadata = {"methods_placement": "after_bibliography"}
+        article_md = """## Introduction
+
+This is the introduction.
+
+## Methods
+
+This is the methods section.
+"""
+
+        result = process_template_replacements(template_content, yaml_metadata, article_md)
+
+        # Methods should appear in the METHODS-AFTER-BIBLIOGRAPHY placeholder
+        assert "\\section*{Methods}" in result
+        assert "This is the methods section" in result
+
+    def test_methods_placement_default(self):
+        """Test that default behavior is inline when methods_placement is omitted."""
+        template_content = """<PY-RPL:MAIN-SECTION>
+<PY-RPL:METHODS-AFTER-RESULTS>
+<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>"""
+        yaml_metadata = {}  # No methods_placement setting
+        article_md = """## Introduction
+
+This is the introduction.
+
+## Methods
+
+This is the methods section.
+"""
+
+        result = process_template_replacements(template_content, yaml_metadata, article_md)
+
+        # Default should be inline (Methods in MAIN-SECTION)
+        assert "\\section*{Methods}" in result
+        assert "This is the methods section" in result
